# -*- coding: utf-8 -*-
#
# Copyright (C) 2006-2007 Edgewall Software
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at http://posterity.edgewall.org/wiki/License.
#
# This software consists of voluntary contributions made by many
# individuals. For the exact contribution history, see the revision
# history and logs, available at http://posterity.edgewall.org/log/.

import os

from sqlalchemy import create_engine
from elixir import objectstore, metadata, drop_all
import pkg_resources

from posterity.db import transaction
from posterity.admin import admin
from posterity.model import Account
from posterity.util import encrypt_password

instance_dir = os.tempnam()

def setup_module():
    dburi = os.environ.get('POSTERITY_TEST_DBURI', 'sqlite://')
    engine = create_engine(dburi)
    metadata.connect(engine)
    trans = objectstore.create_transaction()
    transaction._push_object(trans)

def teardown_module():
    transaction.rollback()
    transaction._pop_object()
    objectstore.clear()
    drop_all()

def run_command(args):
    admin.run_admin(['posterity-admin'] + args)

def test_init():
    run_command(['init', '--instance', instance_dir, '--database', 'test:///fixture'])

def test_create_account():
    run_command(['account', '--instance', instance_dir, '--create', 'bob'])
    assert Account.get_by(username='bob')

def test_list_account():
    run_command(['account', '--list', '--instance', instance_dir, ])

def test_password():
    run_command(['account', '--password=secret', '--instance', instance_dir, 
                 'bob'])
    account = Account.get_by(username='bob')
    assert account.password == encrypt_password('secret')

def test_inject():
    emails = pkg_resources.resource_listdir('posterity.admin', 'tests/data')
    for email in emails:
        if not email.endswith('.eml'):
            continue
        filename = pkg_resources.resource_filename('posterity.admin', 
                                                   'tests/data/' + email)
        run_command(['inject', '-f', filename, '--instance', instance_dir, 
                     'bob'])

def test_inject_mbox():
    filename = pkg_resources.resource_filename('posterity.admin', 
                                               'tests/data/test.mbox')
    run_command(['inject', '--mbox', '-f', filename, 
                 '--instance', instance_dir, 'bob'])

